==> sumo-src-0.20.0.tar.gz: sumo-0.20.0/src/netimport/vissim/tempstructs/NIVissimVehicleClass.h <==
/****************************************************************************/
/// @file    NIVissimVehicleClass.h
/// @author  Daniel Krajzewicz
/// @date    Sept 2002
/// @version $Id: NIVissimVehicleClass.h 15692 2014-02-22 09:17:02Z behrisch $
///
// -------------------
/****************************************************************************/
// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
/****************************************************************************/
//
//   This file is part of SUMO.
//   SUMO is free software: you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
/****************************************************************************/
#ifndef NIVissimVehicleClass_h
#define NIVissimVehicleClass_h


// ===========================================================================
// included modules
// ===========================================================================
#ifdef _MSC_VER
#include <windows_config.h>
#else
#include <config.h>
#endif


// ===========================================================================
// class definitions
// ===========================================================================
/**
 *
 */
class NIVissimVehicleClass {
public:
    NIVissimVehicleClass(int type, SUMOReal percentage, int vwish);
    ~NIVissimVehicleClass();
    int getSpeed() const;
private:
    int myType;
    SUMOReal myPercentage;
    int myVWish;
};


#endif

/****************************************************************************/

==> sumo-src-0.22.0.tar.gz: sumo-0.22.0/src/netimport/vissim/tempstructs/NIVissimVehicleClass.h <==
/****************************************************************************/
/// @file    NIVissimVehicleClass.h
/// @author  Daniel Krajzewicz
/// @date    Sept 2002
/// @version $Id: NIVissimVehicleClass.h 17235 2014-11-03 10:53:02Z behrisch $
///
// -------------------
/****************************************************************************/
// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
/****************************************************************************/
//
//   This file is part of SUMO.
//   SUMO is free software: you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
/****************************************************************************/
#ifndef NIVissimVehicleClass_h
#define NIVissimVehicleClass_h


// ===========================================================================
// included modules
// ===========================================================================
#ifdef _MSC_VER
#include <windows_config.h>
#else
#include <config.h>
#endif


// ===========================================================================
// class definitions
// ===========================================================================
/**
 *
 */
class NIVissimVehicleClass {
public:
    NIVissimVehicleClass(int vwish);
    ~NIVissimVehicleClass();
    int getSpeed() const;
private:
    int myVWish;
};


#endif

/****************************************************************************/
